@@ -14,6 +14,12 @@ jomo.glm <-
     }
     if (family == "binomial") {
       stopifnot(is.data.frame(data))
+      if (is_tibble(data)) {
+        data<-data.frame(data)
+        warning("tibbles not supported. data converted to standard data.frame. ")
+      }
+      
+      if (isTRUE(any(sapply(df, is.character)))) stop("Character variables not allowed in data\n")
       stopifnot(any(grepl("~",deparse(formula))))
       fit.cr<-glm(formula,data=data, na.action = na.omit, family=binomial)
       betaY.start<-coef(fit.cr)
@@ -32,12 +38,18 @@ jomo.glm <-
       Y.numcat<-NULL
       for (j in 1:ncol(Ycov)) {
         if (is.numeric(Ycov[,j])) {
-          if (is.null(Y.con)) Y.con<-data.frame(Ycov[,j,drop=FALSE])
-          else Y.con<-data.frame(Y.con,Ycov[,j,drop=FALSE])
+          if (is.null(Y.con)) {
+            Y.con<-data.frame(Ycov[,j,drop=FALSE])
+          } else {
+            Y.con<-data.frame(Y.con,Ycov[,j,drop=FALSE])
+          }
         }
         if (is.factor(Ycov[,j])) {
-          if (is.null(Y.cat)) Y.cat<-data.frame(Ycov[,j,drop=FALSE])
-          else Y.cat<-data.frame(Y.cat,Ycov[,j,drop=FALSE])
+          if (is.null(Y.cat)) {
+            Y.cat<-data.frame(Ycov[,j,drop=FALSE])
+          } else {
+            Y.cat<-data.frame(Y.cat,Ycov[,j,drop=FALSE])
+          }
           Y.numcat<-cbind(Y.numcat,nlevels(Ycov[,j]))
         }
       }
