@@ -26,7 +26,7 @@ jomo1con<- function(Y, X=NULL, beta.start=NULL, l1cov.start=NULL, l1cov.prior=NU
       n.patterns<-nrow(miss.pat)-1
     }
   } else {
-    miss.pat<-matrix(0,2,ncol(Y)+1)
+    miss.pat<-matrix(0,2,ncol(Y))
     n.patterns<-nrow(miss.pat)-1
   }
   
