@@ -11,6 +11,35 @@ jomo2com <-
     if (is.null(l2.beta.start)) l2.beta.start=matrix(0,ncol(X2),(max(0,ncol(Y2.con))+max(0,(sum(Y2.numcat)-length(Y2.numcat)))))
     if (is.null(l1cov.start)) l1cov.start=diag(1,ncol(beta.start))
     if (is.null(l1cov.prior)) l1cov.prior=diag(1,ncol(l1cov.start))
+    if (is_tibble(Y.con)) {
+      Y.con<-data.frame(Y.con)
+      warning("tibbles not supported. Y.con converted to standard data.frame. ")
+    }
+    if (is_tibble(Y.cat)) {
+      Y.cat<-data.frame(Y.cat)
+      warning("tibbles not supported. Y.cat converted to standard data.frame. ")
+    }
+    if (is_tibble(Y2.con)) {
+      Y2.con<-data.frame(Y2.con)
+      warning("tibbles not supported. Y2.con converted to standard data.frame. ")
+    }
+    if (is_tibble(Y2.cat)) {
+      Y2.cat<-data.frame(Y2.cat)
+      warning("tibbles not supported. Y2.cat converted to standard data.frame. ")
+    }
+    if (is_tibble(X)) {
+      X<-data.frame(X)
+      warning("tibbles not supported. X converted to standard data.frame. ")
+    }
+    if (is_tibble(Z)) {
+      Z<-data.frame(Z)
+      warning("tibbles not supported. Z converted to standard data.frame. ")
+    }
+    if (is_tibble(X2)) {
+      X2<-data.frame(X2)
+      warning("tibbles not supported. X2 converted to standard data.frame. ")
+    }
+    
     clus<-factor(unlist(clus))
     previous_levels_clus<-levels(clus)
     levels(clus)<-0:(nlevels(clus)-1)
@@ -138,6 +167,35 @@ jomo2com <-
       Y=Y.cat
       Yi=matrix(0,nrow(Y.cat),(sum(Y.numcat)-length(Y.numcat)))
     }
+    n.patterns<-c(0,0)
+    if (any(is.na(Y))) {
+      if (ncol(Y)==1) {
+        miss.pat<-matrix(c(0,1),2,1)
+        n.patterns[1]<-2
+      } else  {
+        miss.pat<-md.pattern.mice(Y, plot=F)
+        miss.pat<-miss.pat[,colnames(Y)]
+        n.patterns[1]<-nrow(miss.pat)-1
+      }
+    } else {
+      miss.pat<-matrix(0,2,ncol(Y))
+      n.patterns[1]<-nrow(miss.pat)-1
+    }
+    
+    miss.pat.id<-rep(0,nrow(Y))
+    for (i in 1:nrow(Y)) {
+      k <- 1
+      flag <- 0
+      while ((k <= n.patterns[1]) & (flag == 0)) {
+        if (all(!is.na(Y[i,])==miss.pat[k,1:(ncol(miss.pat))])) {
+          miss.pat.id[i] <- k
+          flag <- 1
+        } else {
+          k <- k + 1
+        }
+      }
+    }
+    
     if (!is.null(Y2.con)&isnullcat2==0) {
       Y2=cbind(Y2.con,Y2.cat)
       Y2i=cbind(Y2.con, matrix(0,nrow(Y2.con),(sum(Y2.numcat)-length(Y2.numcat))))
@@ -147,6 +205,33 @@ jomo2com <-
     } else {
       Y2=Y2.cat
       Y2i=matrix(0,nrow(Y2.cat),(sum(Y2.numcat)-length(Y2.numcat)))
+    }
+    if (any(is.na(Y2))) {
+      if (ncol(Y2)==1) {
+        miss.pat2<-matrix(c(0,1),2,1)
+        n.patterns[2]<-2
+      } else  {
+        miss.pat2<-md.pattern.mice(Y2, plot=F)
+        miss.pat2<-miss.pat2[,colnames(Y2)]
+        n.patterns[2]<-nrow(miss.pat2)-1
+      }
+    } else {
+      miss.pat2<-matrix(0,2,ncol(Y2))
+      n.patterns[2]<-nrow(miss.pat2)-1
+    }
+    
+    miss.pat.id2<-rep(0,nrow(Y2))
+    for (i in 1:nrow(Y2)) {
+      k <- 1
+      flag <- 0
+      while ((k <= n.patterns[2]) & (flag == 0)) {
+        if (all(!is.na(Y2[i,])==miss.pat2[k,1:(ncol(miss.pat2))])) {
+          miss.pat.id2[i] <- k
+          flag <- 1
+        } else {
+          k <- k + 1
+        }
+      }
     }    
     h=1
     if (isnullcat==0) {
@@ -204,7 +289,7 @@ jomo2com <-
     for (i in 1:nrow(Yi)) for (j in 1:ncol(Yi)) if (is.na(Yimp[i,j])) Yimp2[i,j]=meanobs[j]
     meanobs2<-colMeans(Y2i,na.rm=TRUE)
     for (i in 1:nrow(Y2i)) for (j in 1:ncol(Y2i)) if (is.na(Y2imp[i,j])) Y2imp2[i,j]=meanobs2[j]
-    .Call("jomo2comC", Y, Yimp, Yimp2, Y.cat, Y2, Y2imp,Y2imp2, Y2.cat, X, X2, Z, clus,betait,beta2it,uit,bpost, b2post, upost,covit,opost, covuit, cpost, nburn, l1cov.prior,l2cov.prior,Y.numcat,Y2.numcat, ncolYcon,ncolY2con,out.iter,0, PACKAGE = "jomo")
+    .Call("jomo2comC", Y, Yimp, Yimp2, Y.cat, Y2, Y2imp,Y2imp2, Y2.cat, X, X2, Z, clus,betait,beta2it,uit,bpost, b2post, upost,covit,opost, covuit, cpost, nburn, l1cov.prior,l2cov.prior,Y.numcat,Y2.numcat, ncolYcon,ncolY2con,out.iter,0, miss.pat.id, n.patterns, miss.pat.id2, PACKAGE = "jomo")
     #betapost[,,1]=bpost
     #upostall[,,1]=upost
     #omegapost[,,(1)]=opost
@@ -235,7 +320,7 @@ jomo2com <-
       imp[(i*nrow(clus)+1):((i+1)*nrow(clus)), (ncol(Y)+ncol(Y2)+ncol(X)+ncol(X2)+ncol(Z)+1)]=clus
       imp[(i*nrow(X)+1):((i+1)*nrow(X)), (ncol(Y)+ncol(Y2)+ncol(X)+ncol(X2)+ncol(Z)+2)]=c(1:nrow(Y))
       imp[(i*nrow(X)+1):((i+1)*nrow(X)), (ncol(Y)+ncol(Y2)+ncol(X)+ncol(X2)+ncol(Z)+3)]=i
-      .Call("jomo2comC", Y, Yimp, Yimp2, Y.cat, Y2, Y2imp,Y2imp2, Y2.cat, X, X2, Z, clus,betait,beta2it,uit,bpost,b2post,upost,covit,opost, covuit, cpost, nbetween, l1cov.prior,l2cov.prior,Y.numcat,Y2.numcat, ncolYcon,ncolY2con,out.iter,0, PACKAGE = "jomo")
+      .Call("jomo2comC", Y, Yimp, Yimp2, Y.cat, Y2, Y2imp,Y2imp2, Y2.cat, X, X2, Z, clus,betait,beta2it,uit,bpost,b2post,upost,covit,opost, covuit, cpost, nbetween, l1cov.prior,l2cov.prior,Y.numcat,Y2.numcat, ncolYcon,ncolY2con,out.iter,0, miss.pat.id, n.patterns, miss.pat.id2, PACKAGE = "jomo")
       betapost[,,(i-1)]=bpost
       beta2post[,,(i-1)]=b2post
       upostall[,,(i-1)]=upost
