@@ -840,7 +840,7 @@ for (i=0;i<ns;i++) {
 				if (nmiss>0) {
 					for (k=0;k<JY;k++) {
 						for (t=0;t<JY;t++) {
-							if (ISNAN(REAL(Yimp)[j+k*IY])&ISNAN(REAL(Yimp)[j+t*IY])) {
+							if (ISNAN(REAL(Yimp)[j+k*IY])&&ISNAN(REAL(Yimp)[j+t*IY])) {
 								omegamm[countmm]=REAL(omega)[k+t*Io];
 								countmm++;
 							}
@@ -848,7 +848,7 @@ for (i=0;i<ns;i++) {
 								omegamo[countmo]=REAL(omega)[k+t*Io];
 								countmo++;	
 							}
-							else if (!ISNAN(REAL(Yimp)[j+k*IY])&!ISNAN(REAL(Yimp)[j+t*IY])){
+							else if (!ISNAN(REAL(Yimp)[j+k*IY])&&!ISNAN(REAL(Yimp)[j+t*IY])){
 								omegaoo[countoo]=REAL(omega)[k+t*Io];
 								countoo++;	
 							}
